A dataset containing the population sizes of six taxa and from 1970 until 2032 at every two years. First two species are taken from the same example used by IUCN (2019) to illustrate the assessment of this criterion.

data(example_criterionA)

Format

A data frame with six rows and 33 variables