A dataset containing the population sizes adapted from some of the panels provided in Figure 4.4. of IUCN (2019) to illustrate different examples of how population can fluctuate.

data(example_fluctuation)

Format

A data frame with seven rows and 28 variables