A dataset containing occurrence records and population size estimates from three arborescent species from the Atlantic Forest obtained from different sources, but mostly from GBIF and TreeCo.

data(example_tutorial)

Format

A named list with two data frames: 'occurrences' and 'population.sizes'

Details

Only occurrence records considered to have a high confidence level in terms of georefferencing and species identifications are included.

In data frame 'occurrences' columns are: ddlat, ddlon, tax, coly, UC, source

In data frame 'population.sizes' columns are: species, and all years with population estimates