Subpopulations estimation

subpop.estimation(XY, resol_sub_pop, export_shp = FALSE, proj_type = "cea")

Arguments

XY

data.frame with first two columns are projected coordinates (numeric)

resol_sub_pop

numeric. Defines the radius of the circles around each occurrence, in kilometres.

export_shp

logical. Whether the resulting shapefiles should be exported. FALSE by default.

proj_type

string or numeric