R/dataset.ex.R
example_criterionC.RdA dataset containing the population sizes for nine different taxa and from 1970 until 2000 at every five years, without information on subpopulation sizes.
data(example_criterionC)A data frame with 9 rows and 7 variables