R/dataset.ex.R
example_fluctuation.RdA dataset containing the population sizes adapted from some of the panels provided in Figure 4.4. of IUCN (2019) to illustrate different examples of how population can fluctuate.
data(example_fluctuation)A data frame with seven rows and 28 variables